import phonenumbers


def validate_mobile(mobile):
    if not mobile or not mobile.startswith('+') or not mobile[1:].isdigit():
        return False
    try:
        x = phonenumbers.parse(mobile, 'IN')  # Default region sets to 'IN'
        if not phonenumbers.is_valid_number_for_region(x,'IN'):
            return False 
    except phonenumbers.phonenumberutil.NumberParseException:
        return False
    return True
 


"""
Helpr package initialization.
"""
__version__ = "0.2.13"

from .common_utils import validate_mobile
from .exceptions import AppException
from .format_response import jsonify_success, jsonify_failure
from .secret_manager import SecretManager
from .cache import (
    RedisHelper,
    CacheDatabase,
    BulkRedisAction,
    BulkRedisActionType
)
from .token_service import JWTHelper, TokenError, TokenMissingError, TokenExpiredError, TokenInvalidError
from .cdn import Cdn
from .logger import logger
from .s3_helper import upload_to_s3

__all__ = [
    'validate_mobile',
    'AppException',
    'jsonify_success',
    'jsonify_failure',
    'SecretManager',
    'RedisHelper',
    'CacheDatabase',
    'BulkRedisAction',
    'BulkRedisActionType',
    'JWTHelper',
    'TokenError',
    'TokenMissingError',
    'TokenExpiredError',
    'TokenInvalidError',
    'Cdn',
    'logger',
    'upload_to_s3'
]





class Cdn:
    def __init__(self):
        self.mapping = {
            "d-medusa-media": 'https://ik.imagekit.io/lyu8ar8mu/',
            "d-review-media": 'https://ik.imagekit.io/lyu8ar8mu/review-media/'
        }
        self.supported_extensions = ['jpg', 'jpeg', 'png', 'gif', 'svg', 'webp','avif']
    
    def get_edge_url(self, url: str, region: str = None):
        if url is None:
            return None
            
        if not isinstance(url, str):
            return url
        
        if url.lower().split('?')[0].split('.')[-1] not in self.supported_extensions:
            return url
        
        # Build exhaustive mapping using the provided region
        exhaustive_mapping = {}
        for key, value in self.mapping.items():
            if region:
                exhaustive_mapping[f"http://{key}.s3.{region}.amazonaws.com/"] = value
                exhaustive_mapping[f"https://{key}.s3.{region}.amazonaws.com/"] = value
            exhaustive_mapping[f"http://{key}.s3.amazonaws.com/"] = value
            exhaustive_mapping[f"https://{key}.s3.amazonaws.com/"] = value
        
        for key, value in exhaustive_mapping.items():
            if key in url:
                return url.replace(key, value)
                
        return url


import boto3
from fastapi import HTTPException, UploadFile
from botocore.exceptions import BotoCoreError, ClientError

def upload_to_s3(
    file: UploadFile,
    key: str,
    bucket_name: str,
    region: str
) -> str:
    """
    Upload a file to AWS S3.

    Args:
        file (UploadFile): File to upload (from FastAPI UploadFile).
        key (str): S3 object key (path + filename).
        bucket_name (str): S3 bucket name.
        region (str): AWS region name.

    Returns:
        str: Public URL of uploaded file.

    Raises:
        HTTPException: On AWS errors or invalid input.
    """
    s3_client = boto3.client("s3", region_name=region)

    try:
        s3_client.upload_fileobj(
            file.file,
            bucket_name,
            key,
            ExtraArgs={"ContentType": file.content_type}
        )
    except ClientError as e:
        # AWS client-side error
        raise HTTPException(
            status_code=500,
            detail=f"Failed to upload file to S3: {e.response['Error']['Message']}"
        )
    except BotoCoreError as e:
        # AWS core error
        raise HTTPException(
            status_code=500,
            detail=f"Unexpected AWS error during upload: {str(e)}"
        )
    except Exception as e:
        # Other errors
        raise HTTPException(
            status_code=500,
            detail=f"Unexpected error during upload: {str(e)}"
        )

    file_url = f"https://{bucket_name}.s3.{region}.amazonaws.com/{key}"
    return file_url



from setuptools import setup, find_packages
import re
from pathlib import Path

def get_version():
    """Get the version from __init__.py"""
    init_file = Path("helpr/__init__.py").read_text()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", init_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Version string not found in __init__.py")

def read_file(file):
    """Read a file and return its content."""
    try:
        with open(file, encoding="utf-8") as f:
            return f.read().strip()
    except FileNotFoundError:
        return ""

# Runtime dependencies - these are the only ones that will be installed with the package
install_requires = [
    "boto3>=1.35.81",
    "botocore>=1.35.81",
    "fastapi>=0.115.6",
    "redis>=4.5.0",
    "Authlib>=1.2.0",
    "pydantic==2.10.2",
    "typing_extensions>=4.12.2"
]

setup(
    name="helpr",
    version=get_version(),
    author="Clinikally",
    author_email="dev@clinikally.com",
    description="A utility package for Clinikally applications",
    long_description=read_file("README.md"),
    long_description_content_type="text/markdown",
    url="https://github.com/clinikally/helpr",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    python_requires=">=3.9",
    install_requires=install_requires,
)